rotate-backups: Simple command line interface for backup rotation
=================================================================

Welcome to the documentation of `rotate-backups` version |release|!
The following sections are available:

.. contents::
   :local:

User documentation
------------------

The readme is the best place to start reading, it's targeted at all users and
documents the command line interface:

.. toctree::
   readme.rst

API documentation
-----------------

The following API documentation is automatically generated from the source code:

.. toctree::
   api.rst

Change log
----------

The change log lists notable changes to the project:

.. toctree::
   changelog.rst

